==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_en_hx.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=en_hx
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>1mp0r74n7 gr0up:</b> 17 15 v3ry 57r0ng1y 4dv153d 70 5313c7 4 k3yw0rd 1n 7h15 gr0up.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => '5173 4dm1n157r470r5',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => '3d170r5',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'v15170r5 0f 7h3 pub11c 5173 wh3n 7h3y p057 4 m3554g3 0n 4 f0rum.',

	// I
	'icone_creation_groupe_mots' => 'Cr3473 4 n3w k3yw0rd gr0up',
	'icone_creation_mots_cles' => 'Cr3473 4 n3w k3yw0rd',
	'icone_modif_groupe_mots' => 'M0d1fy 7h15 k3yw0rd gr0up',
	'icone_mots_cles' => 'K3yw0rd5',
	'icone_supprimer_groupe_mots' => 'D31373 7h15 gr0up',
	'icone_voir_tous_mots_cles' => '5h0w 411 k3yw0rd5',
	'info_articles_lies_mot' => '4r71c135 4550c1473d w17h 7h15 k3yw0rd',
	'info_changer_nom_groupe' => 'Ch4ng3 7h3 n4m3 0f 7h15 gr0up:',
	'info_creation_mots_cles' => 'Cr3473 4nd c0nf1gur3 7h3 5173’5 k3yw0rd5 h3r3',
	'info_dans_groupe' => '1n gr0up:',
	'info_delet_mots_cles' => 'Y0u r3qu3573d 7h3 d313710n 0f k3yw0rd
<b>@titre_mot@</b> (@type_mot@). 7h15 k3yw0rd b31ng 11nk3d 70
<b>@texte_lie@</b>y0u mu57 c0nf1rm 7h15 d3c1510n:', # MODIF
	'info_groupe_important' => '1mp0r74n7 gr0up',
	'info_mots_cles' => 'K3yw0rd5',
	'info_mots_cles_association' => 'K3yw0rd5 1n 7h15 gr0up c4n b3 4550c1473d w17h:',
	'info_oui_suppression_mot_cle' => '1 w4n7 70 d31373 7h15 k3yw0rd p3rm4n3n71y.',
	'info_question_mots_cles' => 'D0 y0u w15h 70 u53 k3yw0rd5 1n y0ur 5173?',
	'info_qui_attribue_mot_cle' => 'K3yw0rd5 1n 7h15 gr0up c4n b3 4551gn3d by:',
	'info_retirer_mot' => 'R3m0v3 7h15 k3yw0rd',
	'info_retirer_mots' => 'R3m0v3 411 k3yw0rd5',
	'info_rubriques_liees_mot' => '53c710n5 4550c1473d w17h 7h15 k3yw0rd',
	'info_selection_un_seul_mot_cle' => 'Y0u c4n 5313c7 <b>0n1y 0n3 k3yw0rd</b> 47 4 71m3 1n 7h15 gr0up.', # MODIF
	'info_supprimer_mot' => 'd31373 7h15 k3yw0rd',
	'info_titre_mot_cle' => 'N4m3 0r 71713 0f 7h15 k3yw0rd',
	'info_un_mot' => '0n3 k3yw0rd 47 4 71m3',
	'item_ajout_mots_cles' => '4u7h0r153 7h3 4dd1710n 0f k3yw0rd5 70 f0rum5',
	'item_non_ajout_mots_cles' => 'D0 n07 4u7h0r153 7h3 4dd1710n 0f k3yw0rd5 70 f0rum5',
	'item_non_utiliser_config_groupe_mots_cles' => 'D0 n07 u53 7h3 4dv4nc3d c0nf1gur4710n 0f k3yw0rd gr0up5',
	'item_non_utiliser_mots_cles' => 'D0 n07 u53 k3yw0rd5',
	'item_utiliser_config_groupe_mots_cles' => 'U53 7h3 4dv4nc3d c0nf1gur4710n 0f k3yw0rd gr0up5',
	'item_utiliser_mots_cles' => 'U53 k3yw0rd5',

	// L
	'logo_mot_cle' => 'K3YW0RD’5 10G0',

	// T
	'texte_config_groupe_mots_cles' => 'D0 y0u w15h 70 4c71v473 7h3 4dv4nc3d c0nf1gur4710n k3yw0rd gr0up5,
			by 5p3c1fy1ng, f0r 1n574nc3 7h47 4 un1qu3 w0rd p3r gr0up
			c0u1d b3 5313c73d, 7h47 4 gr0up 15 1mp0r74n7...?', # MODIF
	'texte_mots_cles' => 'K3yw0rd5 4110w y0u 70 cr3473 70p1c41 11nk5 b37w33n y0ur 4r71c135
  1rr35p3c71v3 0f 7h31r 53c710n 10c4710n. 7h47 w4y y0u c4n
  3nr1ch 7h3 n4v1g4710n 0f y0ur 5173 0r 3v3n u53 7h353 pr0p3r7135
  70 cu570m153 7h3 4r71c135 1n y0ur 73mp14735.',
	'texte_mots_cles_dans_forum' => 'D0 y0u w15h 70 4110w 7h3 u53 0f k3yw0rd5 7h47 c0u1d b3 5313c73d by v15170r5, 1n 7h3 pub11c 5173 f0rum5? (W4rn1ng: 7h15 0p710n 15 r47h3r 1n7r1c473 70 u53 pr0p3r1y.)',
	'texte_nouveau_mot' => 'N3w k3yw0rd',
	'titre_config_groupe_mots_cles' => 'C0nf1gur4710n 0f 7h3 k3yw0rd gr0up5',
	'titre_gauche_mots_edit' => 'K3YW0RD NUMB3R:',
	'titre_mots_cles_dans_forum' => 'K3yw0rd5 1n 7h3 pub11c 5173 f0rum5',
	'titre_mots_tous' => 'K3yw0rd5',
	'titre_nouveau_groupe' => 'N3w gr0up',
	'titre_page_mots_tous' => 'K3yw0rd5'
);

==> spip_4.4.5+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_en_hx.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=en_hx
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>1mp0r74n7 gr0up:</b> 17 15 v3ry 57r0ng1y 4dv153d 70 5313c7 4 k3yw0rd 1n 7h15 gr0up.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => '5173 4dm1n157r470r5',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => '3d170r5',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'v15170r5 0f 7h3 pub11c 5173 wh3n 7h3y p057 4 m3554g3 0n 4 f0rum.',

	// I
	'icone_creation_groupe_mots' => 'Cr3473 4 n3w k3yw0rd gr0up',
	'icone_creation_mots_cles' => 'Cr3473 4 n3w k3yw0rd',
	'icone_modif_groupe_mots' => 'M0d1fy 7h15 k3yw0rd gr0up',
	'icone_mots_cles' => 'K3yw0rd5',
	'icone_supprimer_groupe_mots' => 'D31373 7h15 gr0up',
	'icone_voir_tous_mots_cles' => '5h0w 411 k3yw0rd5',
	'info_articles_lies_mot' => '4r71c135 4550c1473d w17h 7h15 k3yw0rd',
	'info_changer_nom_groupe' => 'Ch4ng3 7h3 n4m3 0f 7h15 gr0up:',
	'info_creation_mots_cles' => 'Cr3473 4nd c0nf1gur3 7h3 5173’5 k3yw0rd5 h3r3',
	'info_dans_groupe' => '1n gr0up:',
	'info_delet_mots_cles' => 'Y0u r3qu3573d 7h3 d313710n 0f k3yw0rd
<b>@titre_mot@</b> (@type_mot@). 7h15 k3yw0rd b31ng 11nk3d 70
<b>@texte_lie@</b>y0u mu57 c0nf1rm 7h15 d3c1510n:', # MODIF
	'info_groupe_important' => '1mp0r74n7 gr0up',
	'info_mots_cles' => 'K3yw0rd5',
	'info_mots_cles_association' => 'K3yw0rd5 1n 7h15 gr0up c4n b3 4550c1473d w17h:',
	'info_oui_suppression_mot_cle' => '1 w4n7 70 d31373 7h15 k3yw0rd p3rm4n3n71y.',
	'info_question_mots_cles' => 'D0 y0u w15h 70 u53 k3yw0rd5 1n y0ur 5173?',
	'info_qui_attribue_mot_cle' => 'K3yw0rd5 1n 7h15 gr0up c4n b3 4551gn3d by:',
	'info_retirer_mot' => 'R3m0v3 7h15 k3yw0rd',
	'info_retirer_mots' => 'R3m0v3 411 k3yw0rd5',
	'info_rubriques_liees_mot' => '53c710n5 4550c1473d w17h 7h15 k3yw0rd',
	'info_selection_un_seul_mot_cle' => 'Y0u c4n 5313c7 <b>0n1y 0n3 k3yw0rd</b> 47 4 71m3 1n 7h15 gr0up.', # MODIF
	'info_supprimer_mot' => 'd31373 7h15 k3yw0rd',
	'info_titre_mot_cle' => 'N4m3 0r 71713 0f 7h15 k3yw0rd',
	'info_un_mot' => '0n3 k3yw0rd 47 4 71m3',
	'item_ajout_mots_cles' => '4u7h0r153 7h3 4dd1710n 0f k3yw0rd5 70 f0rum5',
	'item_non_ajout_mots_cles' => 'D0 n07 4u7h0r153 7h3 4dd1710n 0f k3yw0rd5 70 f0rum5',
	'item_non_utiliser_config_groupe_mots_cles' => 'D0 n07 u53 7h3 4dv4nc3d c0nf1gur4710n 0f k3yw0rd gr0up5',
	'item_non_utiliser_mots_cles' => 'D0 n07 u53 k3yw0rd5',
	'item_utiliser_config_groupe_mots_cles' => 'U53 7h3 4dv4nc3d c0nf1gur4710n 0f k3yw0rd gr0up5',
	'item_utiliser_mots_cles' => 'U53 k3yw0rd5',

	// L
	'logo_mot_cle' => 'K3YW0RD’5 10G0',

	// T
	'texte_config_groupe_mots_cles' => 'D0 y0u w15h 70 4c71v473 7h3 4dv4nc3d c0nf1gur4710n k3yw0rd gr0up5,
			by 5p3c1fy1ng, f0r 1n574nc3 7h47 4 un1qu3 w0rd p3r gr0up
			c0u1d b3 5313c73d, 7h47 4 gr0up 15 1mp0r74n7...?', # MODIF
	'texte_mots_cles' => 'K3yw0rd5 4110w y0u 70 cr3473 70p1c41 11nk5 b37w33n y0ur 4r71c135
  1rr35p3c71v3 0f 7h31r 53c710n 10c4710n. 7h47 w4y y0u c4n
  3nr1ch 7h3 n4v1g4710n 0f y0ur 5173 0r 3v3n u53 7h353 pr0p3r7135
  70 cu570m153 7h3 4r71c135 1n y0ur 73mp14735.',
	'texte_mots_cles_dans_forum' => 'D0 y0u w15h 70 4110w 7h3 u53 0f k3yw0rd5 7h47 c0u1d b3 5313c73d by v15170r5, 1n 7h3 pub11c 5173 f0rum5? (W4rn1ng: 7h15 0p710n 15 r47h3r 1n7r1c473 70 u53 pr0p3r1y.)',
	'texte_nouveau_mot' => 'N3w k3yw0rd',
	'titre_config_groupe_mots_cles' => 'C0nf1gur4710n 0f 7h3 k3yw0rd gr0up5',
	'titre_gauche_mots_edit' => 'K3YW0RD NUMB3R:',
	'titre_mots_cles_dans_forum' => 'K3yw0rd5 1n 7h3 pub11c 5173 f0rum5',
	'titre_mots_tous' => 'K3yw0rd5',
	'titre_nouveau_groupe' => 'N3w gr0up',
	'titre_page_mots_tous' => 'K3yw0rd5',
];
